Django Nomad Notifier — django-nomad-notifier 1.0.1 documentation

### Navigation

- index
- next |
- django-nomad-notifier 1.0.1 documentation »

# Django Nomad Notifier

## Overview

This Django app provides a way to implement a notification system for the users of web apps that must receive updates from the site activity through the following channels:

- Email notifications: they call them transactional emails nowadays. Messages like “Hi Frankie, Jimbo is now following you on SomeSocialFoo.com”.
- Web notifications: displayed/listed on UI (“ala” social apps such as Facebook or Google+). A list of notifications that can be marked as read.

Contents:

- Installation
  - Dependencies
  - Initial setup
- Usage
  - Creating notification models
  - Subclassing `models.Notification`
  - Sending email notifications
  - Displaying web notifications

### Navigation

- index
- next |
- django-nomad-notifier 1.0.1 documentation »